==> knative-model-4.7.1-sources.jar: annotations/io/fabric8/knative/serving/v1alpha1/ConfigurationFluentImpl.java <==
package io.fabric8.knative.serving.v1alpha1;

import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.StringBuffer;
import java.lang.Object;

public class ConfigurationFluentImpl<A extends io.fabric8.knative.serving.v1alpha1.ConfigurationFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.knative.serving.v1alpha1.ConfigurationFluent<A>{

    private String apiVersion;
    private String kind;
    private ObjectMetaBuilder metadata;
    private io.fabric8.knative.serving.v1alpha1.ConfigurationSpecBuilder spec;
    private io.fabric8.knative.serving.v1alpha1.ConfigurationStatusBuilder status;

    public ConfigurationFluentImpl(){
    }
    public ConfigurationFluentImpl(io.fabric8.knative.serving.v1alpha1.Configuration instance){
            this.withApiVersion(instance.getApiVersion()); 
            this.withKind(instance.getKind()); 
            this.withMetadata(instance.getMetadata()); 
            this.withSpec(instance.getSpec()); 
            this.withStatus(instance.getStatus()); 
    }

    public String getApiVersion(){
            return this.apiVersion;
    }

    public A withApiVersion(String apiVersion){
            this.apiVersion=apiVersion; return (A) this;
    }

    public Boolean hasApiVersion(){
            return this.apiVersion != null;
    }

    public A withNewApiVersion(String arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuilder arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuffer arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public String getKind(){
            return this.kind;
    }

    public A withKind(String kind){
            this.kind=kind; return (A) this;
    }

    public Boolean hasKind(){
            return this.kind != null;
    }

    public A withNewKind(String arg1){
            return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuilder arg1){
            return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuffer arg1){
            return (A)withKind(new String(arg1));
    }

    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ObjectMeta getMetadata(){
            return this.metadata!=null?this.metadata.build():null;
    }

    public ObjectMeta buildMetadata(){
            return this.metadata!=null?this.metadata.build():null;
    }

    public A withMetadata(ObjectMeta metadata){
            _visitables.get("metadata").remove(this.metadata);
            if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} return (A) this;
    }

    public Boolean hasMetadata(){
            return this.metadata != null;
    }

    public ConfigurationFluent.MetadataNested<A> withNewMetadata(){
            return new MetadataNestedImpl();
    }

    public ConfigurationFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item){
            return new MetadataNestedImpl(item);
    }

    public ConfigurationFluent.MetadataNested<A> editMetadata(){
            return withNewMetadataLike(getMetadata());
    }

    public ConfigurationFluent.MetadataNested<A> editOrNewMetadata(){
            return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
    }

    public ConfigurationFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item){
            return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
    }

    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public io.fabric8.knative.serving.v1alpha1.ConfigurationSpec getSpec(){
            return this.spec!=null?this.spec.build():null;
    }

    public io.fabric8.knative.serving.v1alpha1.ConfigurationSpec buildSpec(){
            return this.spec!=null?this.spec.build():null;
    }

    public A withSpec(io.fabric8.knative.serving.v1alpha1.ConfigurationSpec spec){
            _visitables.get("spec").remove(this.spec);
            if (spec!=null){ this.spec= new io.fabric8.knative.serving.v1alpha1.ConfigurationSpecBuilder(spec); _visitables.get("spec").add(this.spec);} return (A) this;
    }

    public Boolean hasSpec(){
            return this.spec != null;
    }

    public ConfigurationFluent.SpecNested<A> withNewSpec(){
            return new SpecNestedImpl();
    }

    public ConfigurationFluent.SpecNested<A> withNewSpecLike(io.fabric8.knative.serving.v1alpha1.ConfigurationSpec item){
            return new SpecNestedImpl(item);
    }

    public ConfigurationFluent.SpecNested<A> editSpec(){
            return withNewSpecLike(getSpec());
    }

    public ConfigurationFluent.SpecNested<A> editOrNewSpec(){
            return withNewSpecLike(getSpec() != null ? getSpec(): new io.fabric8.knative.serving.v1alpha1.ConfigurationSpecBuilder().build());
    }

    public ConfigurationFluent.SpecNested<A> editOrNewSpecLike(io.fabric8.knative.serving.v1alpha1.ConfigurationSpec item){
            return withNewSpecLike(getSpec() != null ? getSpec(): item);
    }

    
/**
 * This method has been deprecated, please use method buildStatus instead.
 * @return The buildable object.
 */
@Deprecated public io.fabric8.knative.serving.v1alpha1.ConfigurationStatus getStatus(){
            return this.status!=null?this.status.build():null;
    }

    public io.fabric8.knative.serving.v1alpha1.ConfigurationStatus buildStatus(){
            return this.status!=null?this.status.build():null;
    }

    public A withStatus(io.fabric8.knative.serving.v1alpha1.ConfigurationStatus status){
            _visitables.get("status").remove(this.status);
            if (status!=null){ this.status= new io.fabric8.knative.serving.v1alpha1.ConfigurationStatusBuilder(status); _visitables.get("status").add(this.status);} return (A) this;
    }

    public Boolean hasStatus(){
            return this.status != null;
    }

    public ConfigurationFluent.StatusNested<A> withNewStatus(){
            return new StatusNestedImpl();
    }

    public ConfigurationFluent.StatusNested<A> withNewStatusLike(io.fabric8.knative.serving.v1alpha1.ConfigurationStatus item){
            return new StatusNestedImpl(item);
    }

    public ConfigurationFluent.StatusNested<A> editStatus(){
            return withNewStatusLike(getStatus());
    }

    public ConfigurationFluent.StatusNested<A> editOrNewStatus(){
            return withNewStatusLike(getStatus() != null ? getStatus(): new io.fabric8.knative.serving.v1alpha1.ConfigurationStatusBuilder().build());
    }

    public ConfigurationFluent.StatusNested<A> editOrNewStatusLike(io.fabric8.knative.serving.v1alpha1.ConfigurationStatus item){
            return withNewStatusLike(getStatus() != null ? getStatus(): item);
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            ConfigurationFluentImpl that = (ConfigurationFluentImpl) o;
            if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
            if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
            if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
            if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
            if (status != null ? !status.equals(that.status) :that.status != null) return false;
            return true;
    }


    public class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<ConfigurationFluent.MetadataNested<N>> implements ConfigurationFluent.MetadataNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final ObjectMetaBuilder builder;
    
            MetadataNestedImpl(ObjectMeta item){
                    this.builder = new ObjectMetaBuilder(this, item);
            }
            MetadataNestedImpl(){
                    this.builder = new ObjectMetaBuilder(this);
            }
    
    public N and(){
            return (N) ConfigurationFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata(){
            return and();
    }

}
    public class SpecNestedImpl<N> extends io.fabric8.knative.serving.v1alpha1.ConfigurationSpecFluentImpl<ConfigurationFluent.SpecNested<N>> implements ConfigurationFluent.SpecNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final io.fabric8.knative.serving.v1alpha1.ConfigurationSpecBuilder builder;
    
            SpecNestedImpl(io.fabric8.knative.serving.v1alpha1.ConfigurationSpec item){
                    this.builder = new io.fabric8.knative.serving.v1alpha1.ConfigurationSpecBuilder(this, item);
            }
            SpecNestedImpl(){
                    this.builder = new io.fabric8.knative.serving.v1alpha1.ConfigurationSpecBuilder(this);
            }
    
    public N and(){
            return (N) ConfigurationFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec(){
            return and();
    }

}
    public class StatusNestedImpl<N> extends io.fabric8.knative.serving.v1alpha1.ConfigurationStatusFluentImpl<ConfigurationFluent.StatusNested<N>> implements ConfigurationFluent.StatusNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final io.fabric8.knative.serving.v1alpha1.ConfigurationStatusBuilder builder;
    
            StatusNestedImpl(io.fabric8.knative.serving.v1alpha1.ConfigurationStatus item){
                    this.builder = new io.fabric8.knative.serving.v1alpha1.ConfigurationStatusBuilder(this, item);
            }
            StatusNestedImpl(){
                    this.builder = new io.fabric8.knative.serving.v1alpha1.ConfigurationStatusBuilder(this);
            }
    
    public N and(){
            return (N) ConfigurationFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus(){
            return and();
    }

}


}

==> knative-model-4.10.0-sources.jar: annotations/io/fabric8/knative/serving/v1alpha1/ConfigurationFluentImpl.java <==
package io.fabric8.knative.serving.v1alpha1;

import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.StringBuffer;
import java.lang.Object;

public class ConfigurationFluentImpl<A extends io.fabric8.knative.serving.v1alpha1.ConfigurationFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.knative.serving.v1alpha1.ConfigurationFluent<A>{

    private String apiVersion;
    private String kind;
    private ObjectMetaBuilder metadata;
    private io.fabric8.knative.serving.v1alpha1.ConfigurationSpecBuilder spec;
    private io.fabric8.knative.serving.v1alpha1.ConfigurationStatusBuilder status;

    public ConfigurationFluentImpl(){
    }
    public ConfigurationFluentImpl(io.fabric8.knative.serving.v1alpha1.Configuration instance){
            this.withApiVersion(instance.getApiVersion()); 
            this.withKind(instance.getKind()); 
            this.withMetadata(instance.getMetadata()); 
            this.withSpec(instance.getSpec()); 
            this.withStatus(instance.getStatus()); 
    }

    public String getApiVersion(){
            return this.apiVersion;
    }

    public A withApiVersion(String apiVersion){
            this.apiVersion=apiVersion; return (A) this;
    }

    public Boolean hasApiVersion(){
            return this.apiVersion != null;
    }

    public A withNewApiVersion(String arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuilder arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuffer arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public String getKind(){
            return this.kind;
    }

    public A withKind(String kind){
            this.kind=kind; return (A) this;
    }

    public Boolean hasKind(){
            return this.kind != null;
    }

    public A withNewKind(String arg1){
            return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuilder arg1){
            return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuffer arg1){
            return (A)withKind(new String(arg1));
    }

    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@java.lang.Deprecated public ObjectMeta getMetadata(){
            return this.metadata!=null?this.metadata.build():null;
    }

    public ObjectMeta buildMetadata(){
            return this.metadata!=null?this.metadata.build():null;
    }

    public A withMetadata(ObjectMeta metadata){
            _visitables.get("metadata").remove(this.metadata);
            if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} return (A) this;
    }

    public Boolean hasMetadata(){
            return this.metadata != null;
    }

    public ConfigurationFluent.MetadataNested<A> withNewMetadata(){
            return new MetadataNestedImpl();
    }

    public ConfigurationFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item){
            return new MetadataNestedImpl(item);
    }

    public ConfigurationFluent.MetadataNested<A> editMetadata(){
            return withNewMetadataLike(getMetadata());
    }

    public ConfigurationFluent.MetadataNested<A> editOrNewMetadata(){
            return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
    }

    public ConfigurationFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item){
            return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
    }

    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@java.lang.Deprecated public io.fabric8.knative.serving.v1alpha1.ConfigurationSpec getSpec(){
            return this.spec!=null?this.spec.build():null;
    }

    public io.fabric8.knative.serving.v1alpha1.ConfigurationSpec buildSpec(){
            return this.spec!=null?this.spec.build():null;
    }

    public A withSpec(io.fabric8.knative.serving.v1alpha1.ConfigurationSpec spec){
            _visitables.get("spec").remove(this.spec);
            if (spec!=null){ this.spec= new io.fabric8.knative.serving.v1alpha1.ConfigurationSpecBuilder(spec); _visitables.get("spec").add(this.spec);} return (A) this;
    }

    public Boolean hasSpec(){
            return this.spec != null;
    }

    public ConfigurationFluent.SpecNested<A> withNewSpec(){
            return new SpecNestedImpl();
    }

    public ConfigurationFluent.SpecNested<A> withNewSpecLike(io.fabric8.knative.serving.v1alpha1.ConfigurationSpec item){
            return new SpecNestedImpl(item);
    }

    public ConfigurationFluent.SpecNested<A> editSpec(){
            return withNewSpecLike(getSpec());
    }

    public ConfigurationFluent.SpecNested<A> editOrNewSpec(){
            return withNewSpecLike(getSpec() != null ? getSpec(): new io.fabric8.knative.serving.v1alpha1.ConfigurationSpecBuilder().build());
    }

    public ConfigurationFluent.SpecNested<A> editOrNewSpecLike(io.fabric8.knative.serving.v1alpha1.ConfigurationSpec item){
            return withNewSpecLike(getSpec() != null ? getSpec(): item);
    }

    
/**
 * This method has been deprecated, please use method buildStatus instead.
 * @return The buildable object.
 */
@java.lang.Deprecated public io.fabric8.knative.serving.v1alpha1.ConfigurationStatus getStatus(){
            return this.status!=null?this.status.build():null;
    }

    public io.fabric8.knative.serving.v1alpha1.ConfigurationStatus buildStatus(){
            return this.status!=null?this.status.build():null;
    }

    public A withStatus(io.fabric8.knative.serving.v1alpha1.ConfigurationStatus status){
            _visitables.get("status").remove(this.status);
            if (status!=null){ this.status= new io.fabric8.knative.serving.v1alpha1.ConfigurationStatusBuilder(status); _visitables.get("status").add(this.status);} return (A) this;
    }

    public Boolean hasStatus(){
            return this.status != null;
    }

    public ConfigurationFluent.StatusNested<A> withNewStatus(){
            return new StatusNestedImpl();
    }

    public ConfigurationFluent.StatusNested<A> withNewStatusLike(io.fabric8.knative.serving.v1alpha1.ConfigurationStatus item){
            return new StatusNestedImpl(item);
    }

    public ConfigurationFluent.StatusNested<A> editStatus(){
            return withNewStatusLike(getStatus());
    }

    public ConfigurationFluent.StatusNested<A> editOrNewStatus(){
            return withNewStatusLike(getStatus() != null ? getStatus(): new io.fabric8.knative.serving.v1alpha1.ConfigurationStatusBuilder().build());
    }

    public ConfigurationFluent.StatusNested<A> editOrNewStatusLike(io.fabric8.knative.serving.v1alpha1.ConfigurationStatus item){
            return withNewStatusLike(getStatus() != null ? getStatus(): item);
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            ConfigurationFluentImpl that = (ConfigurationFluentImpl) o;
            if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
            if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
            if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
            if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
            if (status != null ? !status.equals(that.status) :that.status != null) return false;
            return true;
    }


    public class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<ConfigurationFluent.MetadataNested<N>> implements ConfigurationFluent.MetadataNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final ObjectMetaBuilder builder;
    
            MetadataNestedImpl(ObjectMeta item){
                    this.builder = new ObjectMetaBuilder(this, item);
            }
            MetadataNestedImpl(){
                    this.builder = new ObjectMetaBuilder(this);
            }
    
    public N and(){
            return (N) ConfigurationFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata(){
            return and();
    }

}
    public class SpecNestedImpl<N> extends io.fabric8.knative.serving.v1alpha1.ConfigurationSpecFluentImpl<ConfigurationFluent.SpecNested<N>> implements ConfigurationFluent.SpecNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final io.fabric8.knative.serving.v1alpha1.ConfigurationSpecBuilder builder;
    
            SpecNestedImpl(io.fabric8.knative.serving.v1alpha1.ConfigurationSpec item){
                    this.builder = new io.fabric8.knative.serving.v1alpha1.ConfigurationSpecBuilder(this, item);
            }
            SpecNestedImpl(){
                    this.builder = new io.fabric8.knative.serving.v1alpha1.ConfigurationSpecBuilder(this);
            }
    
    public N and(){
            return (N) ConfigurationFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec(){
            return and();
    }

}
    public class StatusNestedImpl<N> extends io.fabric8.knative.serving.v1alpha1.ConfigurationStatusFluentImpl<ConfigurationFluent.StatusNested<N>> implements ConfigurationFluent.StatusNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final io.fabric8.knative.serving.v1alpha1.ConfigurationStatusBuilder builder;
    
            StatusNestedImpl(io.fabric8.knative.serving.v1alpha1.ConfigurationStatus item){
                    this.builder = new io.fabric8.knative.serving.v1alpha1.ConfigurationStatusBuilder(this, item);
            }
            StatusNestedImpl(){
                    this.builder = new io.fabric8.knative.serving.v1alpha1.ConfigurationStatusBuilder(this);
            }
    
    public N and(){
            return (N) ConfigurationFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus(){
            return and();
    }

}


}
